<template>
  <el-dialog
    width="60%"
    title="库存"
    top="5vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    class="stock-dialog"
  >
    <ttable
      :table="table"
      @handleSelectionChange="handleSelectionChange"
      @currentChange="handleCurrentChange"
      :uploadInfo="uploadInfo"
      :prelang="prelang"
      :options="options"
      :bottomOffset="255"
      :ajaxFun="ajaxFun"
      :paramObj="paramObj"
      :selColValArr="paramSelArr"
      :selCol="paramSelCol"
      ref="stockMultiTable"
    >
      <template #toolbar>
        <template>
          <el-form-item
            label="在检测结果登记前是否允许该物料被使用"
            v-if="showIsUsed"
            style="margin: 0"
          >
            <el-radio v-model="isUsed" :label="true" border size="mini"
              >是</el-radio
            >
            <el-radio v-model="isUsed" :label="false" border size="mini"
              >否</el-radio
            >
          </el-form-item>
        </template>
      </template>
    </ttable>

    <div slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取 消</el-button>
      <el-button type="primary" v-thinclick="`saveSelectRow`">确 定</el-button>
    </div>
  </el-dialog>
</template>
<script>
import { fetchList } from '@/api/warehouse/stock'
import ttable from '@/views/common/ztt-table.vue'

export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    paramObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    multiSelect: {
      type: Boolean,
      default: false
    },
    // 默认选中字段的值数组
    paramSelArr: {
      type: Array,
      default: () => {
        return []
      }
    },
    // 默认选中字段
    paramSelCol: {
      type: String
    },
    showIsUsed: {
      type: Boolean,
      default: false
    },
    // 初始条件partNo
    partNo: {
      type: String,
      default: ''
    },
    // 初始条件partName
    partName: {
      type: String,
      default: ''
    }
  },
  data() {
    return {
      ajaxFun: fetchList,
      partsList: [],
      innerVisible: false,
      currentRow: null,
      multipleSelection: [],
      isShowQuery: false,
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: false,
        url: ''
      },
      prelang: 'operation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        cancelRunCreated: true, // 不执行table中的created的getDataList
        defaultOrderBy: { column: 'id', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          {
            width: '100',
            minWidth: '100',
            prop: 'customerOrderNo',
            label: '销售订单号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'partNo',
            label: '零件号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'partName',
            label: '零件名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'warehouseName',
            label: '仓库',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'locationName',
            label: '库位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'systemNo',
            label: '系统编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'partBatchNo',
            label: '零件批号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'stockQuantity',
            label: '库存数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'reserveQuantity',
            label: '预留数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '120',
            prop: 'availableStockQuantity',
            label: '可用库存数量',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'outerColor',
            label: '外护颜色',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'reelNumber',
            label: '载具编号',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            width: '100',
            minWidth: '100',
            prop: 'unit',
            label: '单位',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          }
        ]
      },
      addOrUpdateVisible: false,
      isUsed: false
    }
  },
  components: {
    ttable
  },
  methods: {
    saveSelectRow() {
      if (this.multiSelect) {
        this.$emit('handleSelectionChange', this.multipleSelection, this.isUsed)
      } else {
        this.$emit('listenToPartEvent', this.currentRow)
      }
      this.innerVisible = false
    },
    handleCurrentChange(val) {
      this.currentRow = val
    },
    handleSelectionChange(val) {
      // 多行选中
      this.multipleSelection = val
    },
    // 获取数据列表
    getData() {
      if (this.$refs.stockMultiTable !== undefined) {
        this.$refs.stockMultiTable.getDataList()
      }
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          // 加一下查询条件
          const queryParam = []
          queryParam.push({
            prop: 'partNo',
            searchInfoType: 'text',
            propVal: this.partNo
          })
          queryParam.push({
            prop: 'partName',
            searchInfoType: 'text',
            propVal: this.partName
          })
          this.$refs.stockMultiTable.setQueryParam(queryParam)
          this.getData()
        })
      }
    },
    multiSelect() {
      this.$set(this.options, 'multiSelect', this.multiSelect)
    }
  }
}
</script>
<style>
.stock-dialog .el-dialog__header {
  padding: 10px 20px 10px;
}
.stock-dialog .el-dialog__header .el-dialog__headerbtn {
  top: 10px;
}
.stock-dialog .el-dialog__body {
  padding: 5px 20px;
}

.stock-dialog .el-dialog__footer {
  padding: 5px 20px 10px;
}

.stock-dialog .el-dialog__body .avue-crud__pagination {
  margin-top: 0px;
  margin-bottom: 5px;
}
</style>
